@@ -128,6 +128,15 @@ func TestVerifyIntegrationReusableWorkflow(t *testing.T) {
 		require.NoError(t, err)
 	})
 
+	t.Run("with owner and valid reusable signer repo", func(t *testing.T) {
+		opts := baseOpts
+		opts.Owner = "malancas"
+		opts.SignerRepo = "github/artifact-attestations-workflows"
+
+		err := runVerify(&opts)
+		require.NoError(t, err)
+	})
+
 	t.Run("with repo and valid reusable workflow SAN", func(t *testing.T) {
 		opts := baseOpts
 		opts.Owner = "malancas"
@@ -147,4 +156,82 @@ func TestVerifyIntegrationReusableWorkflow(t *testing.T) {
 		err := runVerify(&opts)
 		require.NoError(t, err)
 	})
+
+	t.Run("with repo and valid reusable signer repo", func(t *testing.T) {
+		opts := baseOpts
+		opts.Owner = "malancas"
+		opts.Repo = "malancas/attest-demo"
+		opts.SignerRepo = "github/artifact-attestations-workflows"
+
+		err := runVerify(&opts)
+		require.NoError(t, err)
+	})
+}
+
+func TestVerifyIntegrationReusableWorkflowSignerWorkflow(t *testing.T) {
+	artifactPath := test.NormalizeRelativePath("../test/data/reusable-workflow-artifact")
+	bundlePath := test.NormalizeRelativePath("../test/data/reusable-workflow-attestation.sigstore.json")
+
+	logger := io.NewTestHandler()
+
+	sigstoreConfig := verification.SigstoreConfig{
+		Logger: logger,
+	}
+
+	cmdFactory := factory.New("test")
+
+	hc, err := cmdFactory.HttpClient()
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	baseOpts := Options{
+		APIClient:        api.NewLiveClient(hc, logger),
+		ArtifactPath:     artifactPath,
+		BundlePath:       bundlePath,
+		Config:           cmdFactory.Config,
+		DigestAlgorithm:  "sha256",
+		Logger:           logger,
+		OCIClient:        oci.NewLiveClient(),
+		OIDCIssuer:       GitHubOIDCIssuer,
+		Owner:            "malancas",
+		Repo:             "malancas/attest-demo",
+		SigstoreVerifier: verification.NewLiveSigstoreVerifier(sigstoreConfig),
+	}
+
+	type testcase struct {
+		name           string
+		signerWorkflow string
+		expectErr      bool
+	}
+
+	testcases := []testcase{
+		{
+			name:           "with invalid signer workflow",
+			signerWorkflow: "foo/bar/.github/workflows/attest.yml",
+			expectErr:      true,
+		},
+		{
+			name:           "valid signer workflow with host",
+			signerWorkflow: "github.com/github/artifact-attestations-workflows/.github/workflows/attest.yml",
+			expectErr:      false,
+		},
+		{
+			name:           "valid signer workflow without host (defaults to github.com)",
+			signerWorkflow: "github/artifact-attestations-workflows/.github/workflows/attest.yml",
+			expectErr:      false,
+		},
+	}
+
+	for _, tc := range testcases {
+		opts := baseOpts
+		opts.SignerWorkflow = tc.signerWorkflow
+
+		err := runVerify(&opts)
+		if tc.expectErr {
+			require.Error(t, err, "expected error for '%s'", tc.name)
+		} else {
+			require.NoError(t, err, "unexpected error for '%s'", tc.name)
+		}
+	}
 }
